# msunpv library
msunpv library for Python 3. The library was created to call api from your msunpv.

See <https://ard-tek.com/> for more information on the MSunPV MD Router Solar.

## Example usage

See [example.py](./example.py) for a basic usage and tests

```code
PYTHONPATH=./src/ python3 example.py <IP>
```